@@ -39,10 +39,10 @@ static constexpr char kSavePasswd[] { "savePasswd" };
 static constexpr char kStashedSmbDevices[] { "StashedSmbDevices" };
 static constexpr char kSavedPasswordType[] { "SavedPasswordType" };
 
-static constexpr char kDaemonService[] { "com.deepin.filemanager.daemon" };
-static constexpr char kDaemonPath[] { "/com/deepin/filemanager/daemon" };
-static constexpr char kDaemonMountPath[] { "/com/deepin/filemanager/daemon/MountControl" };
-static constexpr char kDaemonMountIface[] { "com.deepin.filemanager.daemon.MountControl" };
+static constexpr char kDaemonService[] { "org.deepin.Filemanager.MountControl" };
+static constexpr char kDaemonPath[] { "/org/deepin/Filemanager/MountControl" };
+static constexpr char kDaemonMountPath[] { "/org/deepin/Filemanager/MountControl" };
+static constexpr char kDaemonMountIface[] { "org.deepin.Filemanager.MountControl" };
 static constexpr char kDaemonIntroIface[] { "org.freedesktop.DBus.Introspectable" };
 static constexpr char kDaemonIntroMethod[] { "Introspect" };
 
@@ -197,7 +197,11 @@ void DeviceManager::mountBlockDevAsync(const QString &id, const QVariantMap &opt
             delete fw;
         });
         d->isMountingOptical = true;
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+        fw->setFuture(QtConcurrent::run(&DeviceWatcher::queryOpticalDevUsage, d->watcher, id));
+#else
         fw->setFuture(QtConcurrent::run(d->watcher, &DeviceWatcher::queryOpticalDevUsage, id));
+#endif
     } else {
         QString errMsg;
         if (DeviceHelper::isMountableBlockDev(dev, errMsg)) {
@@ -701,9 +705,10 @@ void DeviceManager::mountNetworkDeviceAsync(const QString &address, CallbackType
 
     static QMap<QString, QString> defaultPort { { "smb", "445" },
                                                 { "ftp", "21" },
-                                                { "sftp", "22" } };
+                                                { "sftp", "22" },
+                                                { "nfs", "2049" } };
     QString host = u.host();
-    QString port = defaultPort.value(u.scheme(), "21");
+    QString port = defaultPort.value(u.scheme());
 
     static QRegularExpression regUrl(R"((\w+)://([^/:]+)(:\d*)?)");
     auto match = regUrl.match(address);
@@ -723,7 +728,9 @@ void DeviceManager::mountNetworkDeviceAsync(const QString &address, CallbackType
     };
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
-    QStringList ports { port };
+    QStringList ports;
+    if (!port.isEmpty())
+        ports.append(port);
     static const QStringList &defaultSmbPorts { "445", "139" };
     if (u.scheme() == "smb" && defaultSmbPorts.contains(port))
         ports = defaultSmbPorts;
@@ -800,13 +807,14 @@ QStringList DeviceManager::detachBlockDev(const QString &id, CallbackType2 cb)
     bool isOptical = me.value(DeviceProperty::kOpticalDrive).toBool();
     bool canPowerOff = me.value(DeviceProperty::kCanPowerOff).toBool();
 
-    auto func = [this, id, isOptical, canPowerOff, cb](bool allUnmounted, const OperationErrorInfo &err) {
+    auto media = me.value(DeviceProperty::kMedia).toString();
+    auto func = [this, id, isOptical, canPowerOff, cb, media](bool allUnmounted, const OperationErrorInfo &err) {
         if (allUnmounted) {
             QThread::msleep(500);   // make a short delay to eject/powerOff, other wise may raise a
-                    // 'device busy' error.
+                                    // 'device busy' error.
             if (isOptical)
                 ejectBlockDevAsync(id, {}, cb);
-            else if (canPowerOff)
+            else if (canPowerOff && media != "flash_sd")   // do not detach SD driver.
                 powerOffBlockDevAsync(id, {}, cb);
             else if (cb)
                 cb(true, err);
@@ -887,7 +895,7 @@ DeviceManager::DeviceManager(QObject *parent)
 {
 }
 
-DeviceManager::~DeviceManager() {}
+DeviceManager::~DeviceManager() { }
 
 void DeviceManager::doAutoMount(const QString &id, DeviceType type, int timeout)
 {
@@ -1051,7 +1059,8 @@ MountPassInfo DeviceManagerPrivate::askForPasswdWhenMountNetworkDevice(const QSt
     dlg.setDomain(domainDefault);
     dlg.setUser(userDefault);
 
-    if (uri.startsWith(Global::Scheme::kFtp) || uri.startsWith(Global::Scheme::kSFtp))
+    QStringList noDomainSchemes { Global::Scheme::kSFtp, Global::Scheme::kFtp, Global::Scheme::kDav, Global::Scheme::kDavs };
+    if (noDomainSchemes.contains(QUrl(uri).scheme()))
         dlg.setDomainLineVisible(false);
 
     DFMMOUNT::MountPassInfo info;
