@@ -12,6 +12,7 @@
 #include <dfm-base/base/application/settings.h>
 #include <dfm-base/base/application/application.h>
 #include <dfm-base/base/device/deviceutils.h>
+#include <dfm-base/utils/universalutils.h>
 
 #include <dfm-framework/dpf.h>
 
@@ -120,7 +121,7 @@ void AbstractWorker::pause()
         return;
     if (speedtimer) {
         elapsed += speedtimer->elapsed();
-        delete speedtimer;
+        speedtimerList.append(speedtimer);
         speedtimer = nullptr;
         JobInfoPointer info(new QMap<quint8, QVariant>);
         info->insert(AbstractJobHandler::NotifyInfoKey::kJobtypeKey, QVariant::fromValue(jobType));
@@ -328,11 +329,11 @@ void AbstractWorker::endWork()
     emit finishedNotify(info);
 
     fmInfo() << "\n work end, job: " << jobType
-            << "\n sources parent: " << (sourceUrls.count() <= 0 ? QUrl() : parentUrl(sourceUrls.first()))
-            << "\n sources count: " << sourceUrls.count()
-            << "\n target: " << targetUrl
-            << "\n time elapsed: " << timeElapsed.elapsed()
-            << "\n";
+             << "\n sources parent: " << (sourceUrls.count() <= 0 ? QUrl() : parentUrl(sourceUrls.first()))
+             << "\n sources count: " << sourceUrls.count()
+             << "\n target: " << targetUrl
+             << "\n time elapsed: " << timeElapsed.elapsed()
+             << "\n";
     fmDebug() << "\n sources urls: " << sourceUrls;
     if (statisticsFilesSizeJob) {
         statisticsFilesSizeJob->stop();
@@ -420,7 +421,7 @@ void AbstractWorker::emitErrorNotify(const QUrl &from, const QUrl &to, const Abs
     emit errorNotify(info);
 
     fmDebug() << "work error, job: " << jobType << " job error: " << error << " url from: " << from << " url to: " << to
-             << " error msg: " << errorMsg << id;
+              << " error msg: " << errorMsg << id;
 }
 
 /*!
@@ -583,7 +584,7 @@ QString AbstractWorker::formatFileName(const QString &fileName)
     if (fs_type == "vfat") {
         QString new_name = fileName;
 
-        return new_name.replace(QRegExp("[\"*:<>?\\|]"), "_");
+        return new_name.replace(QRegularExpression("[\"*:<>?\\|]"), "_");
     }
 
     return fileName;
@@ -640,7 +641,19 @@ void AbstractWorker::saveOperations()
     }
 
     if (handle && isConvert && !completeSourceFiles.isEmpty()) {
-        emit requestSaveRedoOperation(QString::number(quintptr(handle.data()),16), deleteFirstFileSize.load());
+        emit requestSaveRedoOperation(QString::number(quintptr(handle.data()), 16), deleteFirstFileSize.load());
+    }
+    if (jobType == AbstractJobHandler::JobType::kCopyType
+            || jobType == AbstractJobHandler::JobType::kCutType
+            || FileOperationsUtils::canBroadcastPaste()) {
+        QUrl sourceUrl = sourceUrls.isEmpty() ? QUrl() : sourceUrls.first();
+        if (!sourceUrl.isValid() || !targetUrl.isValid()) {
+            fmWarning(logDFMBase()) << "broadcast paste error, cast invalid source or target url!!!"
+                                    << sourceUrl << targetUrl;
+            return;
+        }
+        sourceUrl = parentUrl(sourceUrl);
+        UniversalUtils::boardCastPastData(sourceUrl, targetUrl, completeSourceFiles);
     }
 }
 
@@ -651,9 +664,11 @@ AbstractWorker::~AbstractWorker()
         statisticsFilesSizeJob->wait();
     }
     if (speedtimer) {
-        delete  speedtimer;
+        delete speedtimer;
         speedtimer = nullptr;
     }
+
+    qDeleteAll(speedtimerList);
 }
 
 /*!
