@@ -14,7 +14,11 @@ namespace dfmplugin_propertydialog {
 class PropertyDialog : public dpf::Plugin
 {
     Q_OBJECT
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     Q_PLUGIN_METADATA(IID "org.deepin.plugin.common" FILE "propertydialog.json")
+#else
+    Q_PLUGIN_METADATA(IID "org.deepin.plugin.common.qt6" FILE "propertydialog.json")
+#endif
 
     DPF_EVENT_NAMESPACE(DPPROPERTYDIALOG_NAMESPACE)
 
@@ -27,6 +31,7 @@ class PropertyDialog : public dpf::Plugin
 
     // hook events
     DPF_EVENT_REG_HOOK(hook_PermissionView_Ash)
+    DPF_EVENT_REG_HOOK(hook_PropertyDialog_Disable)
 
 public:
     virtual void initialize() override;
