@@ -36,9 +36,9 @@ DFMBASE_USE_NAMESPACE
 namespace dfmplugin_dirshare {
 
 namespace DaemonServiceIFace {
-static constexpr char kInterfaceService[] { "com.deepin.filemanager.daemon" };
-static constexpr char kInterfacePath[] { "/com/deepin/filemanager/daemon/UserShareManager" };
-static constexpr char kInterfaceInterface[] { "com.deepin.filemanager.daemon.UserShareManager" };
+static constexpr char kInterfaceService[] { "org.deepin.Filemanager.UserShareManager" };
+static constexpr char kInterfacePath[] { "/org/deepin/Filemanager/UserShareManager" };
+static constexpr char kInterfaceInterface[] { "org.deepin.Filemanager.UserShareManager" };
 
 static constexpr char kFuncIsPasswordSet[] { "IsUserSharePasswordSet" };
 static constexpr char kFuncSetPasswd[] { "SetUserSharePassword" };
@@ -239,34 +239,65 @@ void UserShareHelper::startSambaServiceAsync(StartSambaFinished onFinished)
 
 QString UserShareHelper::sharedIP() const
 {
-    QString selfIp;
-    QStringList validIpList;
-    foreach (QNetworkInterface netInterface, QNetworkInterface::allInterfaces()) {
-        if (!netInterface.isValid())
-            continue;
-        QNetworkInterface::InterfaceFlags flags = netInterface.flags();
-        if (!(flags.testFlag(QNetworkInterface::IsRunning) && !flags.testFlag(QNetworkInterface::IsLoopBack)))
-            continue;
-        QList<QNetworkAddressEntry> entryList = netInterface.addressEntries();
-        foreach (QNetworkAddressEntry entry, entryList) {
-            if (!entry.ip().toString().isEmpty() && entry.ip().toString() != "0.0.0.0" && entry.ip().toIPv4Address()) {
-                validIpList << entry.ip().toString();
-            }
+    QString ip = "127.0.0.1";
+    QDBusInterface networkIface("org.freedesktop.NetworkManager",
+                                "/org/freedesktop/NetworkManager",
+                                "org.freedesktop.NetworkManager",
+                                QDBusConnection::systemBus());
+
+    auto primaryConn = networkIface.property("PrimaryConnection").value<QDBusObjectPath>();
+    QDBusInterface actIface("org.freedesktop.NetworkManager",
+                            primaryConn.path(),
+                            "org.freedesktop.NetworkManager.Connection.Active",
+                            QDBusConnection::systemBus());
+
+    auto ipv4CfgPath = actIface.property("Ip4Config").value<QDBusObjectPath>();
+    if (ipv4CfgPath.path().isEmpty()) {
+        fmInfo() << "got invalid ipv4config in" << primaryConn.path();
+        return ip;
+    }
+
+    QDBusInterface ipConfigIface("org.freedesktop.NetworkManager",
+                                 ipv4CfgPath.path(),
+                                 "org.freedesktop.DBus.Properties",
+                                 QDBusConnection::systemBus());
+    QDBusReply<QVariant> reply = ipConfigIface.call("Get",
+                                                    "org.freedesktop.NetworkManager.IP4Config",
+                                                    "AddressData");
+    if (!reply.isValid()) {
+        fmWarning() << "Failed to get AddressData:" << reply.error();
+        return ip;
+    }
+
+    // 解析 aa{sv} 类型
+    const QDBusArgument arg = reply.value().value<QDBusArgument>();
+    if (arg.currentType() != QDBusArgument::ArrayType) {
+        return ip;
+    }
+
+    arg.beginArray();
+    while (!arg.atEnd()) {
+        // 开始处理内层数组元素
+        QVariantMap item;
+        arg >> item;
+        if (!item.value("address", "").toString().isEmpty()) {
+            ip = item.value("address").toString();
+            break;
         }
     }
-    // If multiple IPs are got, just take the first one.
-    // There is not a list control on the UI for the IP.
-    // TODO(zhuangshu):discuss this issue with product manager, or reference the code of dde-network-core plugin.
-    if (validIpList.count() > 0)
-        selfIp = validIpList.first();
+    arg.endArray();
 
-    return selfIp;
+    return ip;
 }
 
 int UserShareHelper::getSharePort() const
 {
     QSettings smbConf("/etc/samba/smb.conf", QSettings::IniFormat);
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     auto ports = smbConf.value("global/smb ports").toString().split(" ", QString::SkipEmptyParts);
+#else
+    auto ports = smbConf.value("global/smb ports").toString().split(" ", Qt::SkipEmptyParts);
+#endif
     return ports.isEmpty() ? -1 : ports.first().toInt();
 }
 
@@ -422,18 +453,17 @@ void UserShareHelper::initMonitorPath()
         watcherManager->add(info.value(ShareInfoKeys::kPath).toString());
 }
 
-void UserShareHelper::removeShareByShareName(const QString &name)
+void UserShareHelper::removeShareByShareName(const QString &name, bool silent)
 {
-    QDBusReply<bool> reply = userShareInter->asyncCall(DaemonServiceIFace::kFuncCloseShare, name, true);
+    QDBusReply<bool> reply = userShareInter->asyncCall(DaemonServiceIFace::kFuncCloseShare, name, !silent);
     if (reply.isValid() && reply.value()) {
         fmDebug() << "share closed: " << name;
+        runNetCmd(QStringList() << "usershare"
+                                << "delete" << name);
     } else {
         fmWarning() << "share close failed: " << name << ", " << reply.error();
         // TODO(xust) regular user cannot remove the sharing which shared by root user. and should raise an error dialog to notify user.
     }
-
-    runNetCmd(QStringList() << "usershare"
-                            << "delete" << name);
 }
 
 void UserShareHelper::removeShareWhenShareFolderDeleted(const QString &deletedPath)
@@ -442,7 +472,7 @@ void UserShareHelper::removeShareWhenShareFolderDeleted(const QString &deletedPa
     if (shareName.isEmpty())
         return;
 
-    removeShareByShareName(shareName);
+    removeShareByShareName(shareName, true);
 }
 
 ShareInfo UserShareHelper::getOldShareByNewShare(const ShareInfo &newShare)
@@ -499,16 +529,17 @@ void UserShareHelper::handleErrorWhenShareFailed(int code, const QString &err) c
 
     // 端口被禁用
     if (err.contains("net usershare add: cannot convert name") && err.contains("{Device Timeout}")) {
-        NetworkUtils::instance()->doAfterCheckNet("127.0.0.1", { "139", "445" },
-                                                  [](bool result) {
-                                                      if (result) {
-                                                          DialogManagerInstance->showErrorDialog(tr("Sharing failed"), "");
-                                                      } else {
-                                                          DialogManagerInstance->showErrorDialog(tr("Sharing failed"),
-                                                                                                 tr("SMB port is banned, please check the firewall strategy."));
-                                                      }
-                                                  },
-                                                  500);
+        NetworkUtils::instance()->doAfterCheckNet(
+                "127.0.0.1", { "139", "445" },
+                [](bool result) {
+                    if (result) {
+                        DialogManagerInstance->showErrorDialog(tr("Sharing failed"), "");
+                    } else {
+                        DialogManagerInstance->showErrorDialog(tr("Sharing failed"),
+                                                               tr("SMB port is banned, please check the firewall strategy."));
+                    }
+                },
+                500);
         return;
     }
 
