@@ -20,7 +20,6 @@
 #include <dfm-framework/dpf.h>
 
 #include <DApplication>
-#include <DApplicationHelper>
 
 #include <QPainter>
 #include <QPainterPath>
@@ -306,7 +305,8 @@ QSize CanvasItemDelegate::paintDragIcon(QPainter *painter, const QStyleOptionVie
     return paintIcon(painter, indexOption.icon,
                      { indexOption.rect, Qt::AlignCenter, QIcon::Normal,
                        QIcon::Off, isThumnailIconIndex(index) })
-            .size();
+            .size()
+            .toSize();
 }
 
 int CanvasItemDelegate::textLineHeight() const
@@ -709,10 +709,10 @@ void CanvasItemDelegate::initStyleOption(QStyleOptionViewItem *option, const QMo
 
     // multi-selected background
     if ((option->state & QStyle::State_HasFocus) && option->showDecorationSelected && model->selectedIndexesCache().size() > 1) {
-        option->palette.setColor(QPalette::Background, QColor("#0076F9"));
+        option->palette.setColor(QPalette::Window, QColor("#0076F9"));
         option->backgroundBrush = QColor("#0076F9");
     } else {   // normal
-        option->palette.setColor(QPalette::Background, QColor("#2da6f7"));
+        option->palette.setColor(QPalette::Window, QColor("#2da6f7"));
         option->backgroundBrush = QColor("#2da6f7");
     }
 
@@ -736,7 +736,7 @@ void CanvasItemDelegate::initStyleOption(QStyleOptionViewItem *option, const QMo
  * \param mode: icon mode (Normal, Disabled, Active, Selected )
  * \param state: The state for which a pixmap is intended to be used. (On, Off)
  */
-QRect CanvasItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, const PaintIconOpts &opts)
+QRectF CanvasItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, const PaintIconOpts &opts)
 {
     // Copy of QStyle::alignedRect
     Qt::Alignment alignment { visualAlignment(painter->layoutDirection(), opts.alignment) };
@@ -759,23 +759,30 @@ QRect CanvasItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, const
         painter->save();
         painter->setRenderHints(painter->renderHints() | QPainter::Antialiasing | QPainter::SmoothPixmapTransform, true);
 
-        QRect backgroundRect { qRound(x), qRound(y), qRound(w), qRound(h) };
-        QRect imageRect { backgroundRect };
+        auto iconStyle { IconUtils::getIconStyle(opts.rect.size().toSize().width()) };
+        QRectF backgroundRect { x, y, w, h };
+        QRectF imageRect { backgroundRect };
+
         // 绘制带有阴影的背景
-        painter->drawPixmap(backgroundRect, IconUtils::renderIconBackground(backgroundRect.size()));
+        auto stroke { iconStyle.stroke };
+        backgroundRect.adjust(-stroke, -stroke, stroke, stroke);
+        const auto &originPixmap { IconUtils::renderIconBackground(backgroundRect.size(), iconStyle) };
+        const auto &shadowPixmap { IconUtils::addShadowToPixmap(originPixmap, iconStyle.shadowOffset, iconStyle.shadowRange, 0.2) };
+        painter->drawPixmap(backgroundRect, shadowPixmap, QRectF());
+        imageRect.adjust(iconStyle.shadowRange, iconStyle.shadowRange, -iconStyle.shadowRange, -iconStyle.shadowRange);
 
-        // 绘制缩略图(上下左右各缩小2px)
-        imageRect.adjust(4, 4, -4, -4);
         QPainterPath clipPath;
-        clipPath.addRoundedRect(imageRect, 4, 4);
+        auto radius { iconStyle.radius - iconStyle.stroke };
+        clipPath.addRoundedRect(imageRect, radius, radius);
         painter->setClipPath(clipPath);
-        painter->drawPixmap(imageRect, px);
+        painter->drawPixmap(imageRect, px, QRectF());
         painter->restore();
+
         return backgroundRect;
     }
-    painter->drawPixmap(qRound(x), qRound(y), px);
+    icon.paint(painter, opts.rect.toRect());
     // return rect before scale
-    return QRect(qRound(x), qRound(y), w, h);
+    return QRectF(x, y, w, h);
 }
 
 QRectF CanvasItemDelegate::paintEmblems(QPainter *painter, const QRectF &rect, const FileInfoPointer &info)
