@@ -22,7 +22,6 @@
 #include <dfm-framework/dpf.h>
 
 #include <DApplication>
-#include <DApplicationHelper>
 
 #include <QPainter>
 #include <QScrollBar>
@@ -734,10 +733,10 @@ void CollectionItemDelegate::initStyleOption(QStyleOptionViewItem *option, const
 
     // multi-selected background
     if ((option->state & QStyle::State_HasFocus) && option->showDecorationSelected && model->selectedIndexes().size() > 1) {
-        option->palette.setColor(QPalette::Background, QColor("#0076F9"));
+        option->palette.setColor(QPalette::Window, QColor("#0076F9"));
         option->backgroundBrush = QColor("#0076F9");
     } else {   // normal
-        option->palette.setColor(QPalette::Background, QColor("#2da6f7"));
+        option->palette.setColor(QPalette::Window, QColor("#2da6f7"));
         option->backgroundBrush = QColor("#2da6f7");
     }
 
@@ -784,22 +783,29 @@ QRect CollectionItemDelegate::paintIcon(QPainter *painter, const QIcon &icon, co
         painter->save();
         painter->setRenderHints(painter->renderHints() | QPainter::Antialiasing | QPainter::SmoothPixmapTransform, true);
 
+        auto iconStyle { IconUtils::getIconStyle(opts.rect.size().toSize().width()) };
         QRect backgroundRect { qRound(x), qRound(y), qRound(w), qRound(h) };
         QRect imageRect { backgroundRect };
-        // 绘制带有阴影的背景
-        painter->drawPixmap(backgroundRect, IconUtils::renderIconBackground(backgroundRect.size()));
 
-        // 绘制缩略图(上下左右各缩小2px)
-        imageRect.adjust(4, 4, -4, -4);
+        // 绘制带有阴影的背景
+        auto stroke { iconStyle.stroke };
+        backgroundRect.adjust(-stroke, -stroke, stroke, stroke);
+        const auto &originPixmap { IconUtils::renderIconBackground(backgroundRect.size(), iconStyle) };
+        const auto &shadowPixmap { IconUtils::addShadowToPixmap(originPixmap, iconStyle.shadowOffset, iconStyle.shadowRange, 0.2) };
+        painter->drawPixmap(backgroundRect, shadowPixmap);
+        imageRect.adjust(iconStyle.shadowRange, iconStyle.shadowRange, -iconStyle.shadowRange, -iconStyle.shadowRange);
+
         QPainterPath clipPath;
-        clipPath.addRoundedRect(imageRect, 4, 4);
+        auto radius { iconStyle.radius - iconStyle.stroke };
+        clipPath.addRoundedRect(imageRect, radius, radius);
         painter->setClipPath(clipPath);
         painter->drawPixmap(imageRect, px);
         painter->restore();
+
         return backgroundRect;
     }
 
-    painter->drawPixmap(qRound(x), qRound(y), px);
+    icon.paint(painter, opts.rect.toRect());
 
     // return rect before scale
     return QRect(qRound(x), qRound(y), w, h);
