@@ -37,18 +37,3 @@ TEST_F(RecentEventReceiverTest, handleWindowUrlChanged)
     st.set_lamda(push, [] { return QVariant(); });
     EXPECT_NO_FATAL_FAILURE(RecentEventReceiver::instance()->handleWindowUrlChanged(123, QUrl("recent:/hello/world")););
 }
-
-TEST_F(RecentEventReceiverTest, initConnect)
-{
-    bool isRun = false;
-    typedef bool (EventDispatcherManager::*Subscribe1)(const QString &, const QString &,
-                                                       RecentEventReceiver *,
-                                                       void (RecentEventReceiver::*)(quint64, QString *));
-    stub.set_lamda(static_cast<Subscribe1>(&EventDispatcherManager::subscribe), [&isRun] {
-        __DBG_STUB_INVOKE__
-        isRun = true;
-        return true;
-    });
-    RecentEventReceiver::instance()->initConnect();
-    EXPECT_TRUE(isRun);
-}
